==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/GambioAdmin/Modules/ProductDownload/App/ProductDownloadReadService.php <==
<?php
/*--------------------------------------------------------------------
 ProductDownloadReadService.php 2021-09-01
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2021 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 -------------------------------------------------------------------*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\ProductDownload\App;

use Gambio\Admin\Modules\ProductDownload\Model\Collections\ProductDownloads;
use Gambio\Admin\Modules\ProductDownload\Model\ProductDownload;
use Gambio\Admin\Modules\ProductDownload\Services\ProductDownloadFactory;
use Gambio\Admin\Modules\ProductDownload\Services\ProductDownloadReadService as ProductDownloadReadServiceInterface;
use Gambio\Admin\Modules\ProductDownload\Services\ProductDownloadRepository as ProductDownloadRepositoryInterface;

/**
 * Class ProductDownloadReadService
 * @package Gambio\Admin\Modules\ProductDownload\App
 */
class ProductDownloadReadService implements ProductDownloadReadServiceInterface
{
    /**
     * @var ProductDownloadRepositoryInterface
     */
    private $repository;
    
    /**
     * @var ProductDownloadFactory
     */
    private $factory;
    
    
    /**
     * ProductDownloadReadService constructor.
     *
     * @param ProductDownloadRepositoryInterface $repository
     * @param ProductDownloadFactory             $factory
     */
    public function __construct(
        ProductDownloadRepositoryInterface $repository,
        ProductDownloadFactory $factory
    ) {
        $this->repository = $repository;
        $this->factory    = $factory;
    }
    
    
    /**
     * @inheritDoc
     */
    public function getProductDownloadsByProductId(int $productId): ProductDownloads
    {
        return $this->repository->getProductDownloadsByProductId($this->factory->createProductId($productId));
    }
    
    
    /**
     * @inheritDoc
     */
    public function getProductDownloadById(int $productOptionId): ProductDownload
    {
        return $this->repository->getProductDownloadById($this->factory->createProductOptionId($productOptionId));
    }
}

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/GambioAdmin/Modules/ProductDownload/App/ProductDownloadReadService.php <==
<?php
/*--------------------------------------------------------------------
 ProductDownloadReadService.php 2023-06-26
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2023 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 -------------------------------------------------------------------*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\ProductDownload\App;

use Gambio\Admin\Modules\Product\Services\ProductDownloadReadService;
use Gambio\Admin\Modules\ProductDownload\Model\Collections\ProductDownloads;
use Gambio\Admin\Modules\ProductDownload\Model\ProductDownload;
use Gambio\Admin\Modules\ProductDownload\Services\ProductDownloadReadService as ProductDownloadReadServiceInterface;

/**
 * Class ProductDownloadReadService
 *
 * @package Gambio\Admin\Modules\ProductDownload\App
 * @deprecated Since 4.7, the gambio shop-system supports submodules. Those product domains were refactored into
 *             submodules too. This class will be deleted with 4.11.
 */
class ProductDownloadReadService implements ProductDownloadReadServiceInterface
{
    public function __construct(private ProductDownloadReadService $proxy) { }
    
    
    /**
     * @inheritDoc
     */
    public function getProductDownloadsByProductId(int $productId): ProductDownloads
    {
        return $this->proxy->getProductDownloadsByProductId($productId);
    }
    
    
    /**
     * @inheritDoc
     */
    public function getProductDownloadById(int $productOptionId): ProductDownload
    {
        return $this->proxy->getProductDownloadById($productOptionId);
    }
}
